@@ -2,11 +2,12 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from product import *
+
+from . import product
 
 
 def register():
     Pool.register(
-        Template,
-        Product,
+        product.Template,
+        product.Product,
         module='product_measurements', type_='model')
